Options

Struct Options 

pub struct Options(/* private fields */);
Option struct containing flags for enabling extra features that are not part of the CommonMark spec.

Implementations

Source

impl Options

pub const ENABLE_TABLES: Options

pub const ENABLE_FOOTNOTES: Options

GitHub-compatible footnote syntax.

Footnotes are referenced with the syntax [^IDENT], and defined with an identifier followed by a colon at top level.


Footnote referenced [^1].

[^1]: footnote defined

Footnote referenced 1.


  1. footnote defined 

pub const ENABLE_STRIKETHROUGH: Options

pub const ENABLE_TASKLISTS: Options

pub const ENABLE_SMART_PUNCTUATION: Options

Enables replacement of ASCII punctuation characters with Unicode ligatures and smart quotes.

This includes replacing -- with , --- with , ... with , "quote" with “quote”, and 'quote' with ‘quote’.

The replacement takes place during the parsing of the document.

pub const ENABLE_HEADING_ATTRIBUTES: Options

Extension to allow headings to have ID and classes.

# text { #id .class1 .class2 myattr other_attr=myvalue } is interpreted as a level 1 heading with the content text, ID id, classes class1 and class2 and custom attributes myattr (without value) and other_attr with value myvalue. Note that ID, classes, and custom attributes should be space-separated.

pub const ENABLE_YAML_STYLE_METADATA_BLOCKS: Options

Metadata blocks in YAML style, i.e.:

  • starting with a --- line
  • ending with a --- or ... line
pub const ENABLE_PLUSES_DELIMITED_METADATA_BLOCKS: Options

Metadata blocks delimited by:

  • +++ line at start
  • +++ line at end
pub const ENABLE_OLD_FOOTNOTES: Options

Older footnote syntax. This flag implies ENABLE_FOOTNOTES, changing it to use an older syntax instead of the new, default, GitHub-compatible syntax.

New syntax is different from the old syntax regarding indentation, nesting, and footnote references with no definition:

[^1]: In new syntax, this is two footnote definitions.
[^2]: In old syntax, this is a single footnote definition with two lines.

[^3]:

    In new syntax, this is a footnote with two paragraphs.

    In old syntax, this is a footnote followed by a code block.

In new syntax, this undefined footnote definition renders as
literal text [^4]. In old syntax, it creates a dangling link.
pub const ENABLE_MATH: Options

With this feature enabled, two events Event::InlineMath and Event::DisplayMath are emitted that conventionally contain TeX formulas.

pub const ENABLE_GFM: Options

Misc GitHub Flavored Markdown features not supported in CommonMark. The following features are currently behind this tag:

  • Blockquote tags ([!NOTE], [!TIP], [!IMPORTANT], [!WARNING], [!CAUTION]).
pub const ENABLE_DEFINITION_LIST: Options

Commonmark-HS-Extensions compatible definition lists.

title 1
  : definition 1
title 2
  : definition 2
pub const ENABLE_SUPERSCRIPT: Options

pub const ENABLE_SUBSCRIPT: Options

Obsidian-style Wikilinks.

Source

impl Options

pub const fn empty() -> Options

Get a flags value with all bits unset.

pub const fn all() -> Options

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Options>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Options

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Options

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Options>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Options) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Options) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Options)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Options)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Options)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Options, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Options) -> Options

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Options) -> Options

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Options) -> Options

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Options) -> Options

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Options

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl Options

pub const fn iter(&self) -> Iter<Options>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Options>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.