pub struct Options(/* private fields */);Expand description
Option struct containing flags for enabling extra features that are not part of the CommonMark spec.
Implementations
Sourceimpl Options
impl Options
pub const ENABLE_TABLES: Options
Sourcepub const ENABLE_FOOTNOTES: Options
pub const ENABLE_FOOTNOTES: Options
pub const ENABLE_STRIKETHROUGH: Options
pub const ENABLE_TASKLISTS: Options
Sourcepub const ENABLE_SMART_PUNCTUATION: Options
pub const ENABLE_SMART_PUNCTUATION: Options
Enables replacement of ASCII punctuation characters with Unicode ligatures and smart quotes.
This includes replacing -- with —, --- with —, ... with …,
"quote" with “quote”, and 'quote' with ‘quote’.
The replacement takes place during the parsing of the document.
Sourcepub const ENABLE_HEADING_ATTRIBUTES: Options
pub const ENABLE_HEADING_ATTRIBUTES: Options
Extension to allow headings to have ID and classes.
# text { #id .class1 .class2 myattr other_attr=myvalue }
is interpreted as a level 1 heading
with the content text, ID id, classes class1 and class2 and
custom attributes myattr (without value) and
other_attr with value myvalue.
Note that ID, classes, and custom attributes should be space-separated.
Sourcepub const ENABLE_YAML_STYLE_METADATA_BLOCKS: Options
pub const ENABLE_YAML_STYLE_METADATA_BLOCKS: Options
Metadata blocks in YAML style, i.e.:
- starting with a
---line - ending with a
---or...line
Sourcepub const ENABLE_PLUSES_DELIMITED_METADATA_BLOCKS: Options
pub const ENABLE_PLUSES_DELIMITED_METADATA_BLOCKS: Options
Metadata blocks delimited by:
+++line at start+++line at end
Sourcepub const ENABLE_OLD_FOOTNOTES: Options
pub const ENABLE_OLD_FOOTNOTES: Options
Older footnote syntax. This flag implies ENABLE_FOOTNOTES, changing it to use an
older syntax instead of the new, default, GitHub-compatible syntax.
New syntax is different from the old syntax regarding indentation, nesting, and footnote references with no definition:
[^1]: In new syntax, this is two footnote definitions.
[^2]: In old syntax, this is a single footnote definition with two lines.
[^3]:
In new syntax, this is a footnote with two paragraphs.
In old syntax, this is a footnote followed by a code block.
In new syntax, this undefined footnote definition renders as
literal text [^4]. In old syntax, it creates a dangling link.Sourcepub const ENABLE_MATH: Options
pub const ENABLE_MATH: Options
With this feature enabled, two events Event::InlineMath and Event::DisplayMath
are emitted that conventionally contain TeX formulas.
Sourcepub const ENABLE_GFM: Options
pub const ENABLE_GFM: Options
Misc GitHub Flavored Markdown features not supported in CommonMark. The following features are currently behind this tag:
- Blockquote tags ([!NOTE], [!TIP], [!IMPORTANT], [!WARNING], [!CAUTION]).
Sourcepub const ENABLE_DEFINITION_LIST: Options
pub const ENABLE_DEFINITION_LIST: Options
Commonmark-HS-Extensions compatible definition lists.
title 1
: definition 1
title 2
: definition 2pub const ENABLE_SUPERSCRIPT: Options
pub const ENABLE_SUBSCRIPT: Options
Sourcepub const ENABLE_WIKILINKS: Options
pub const ENABLE_WIKILINKS: Options
Obsidian-style Wikilinks.
Sourceimpl Options
impl Options
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Options>
pub const fn from_bits(bits: u32) -> Option<Options>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Options
pub const fn from_bits_truncate(bits: u32) -> Options
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Options
pub const fn from_bits_retain(bits: u32) -> Options
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Options>
pub fn from_name(name: &str) -> Option<Options>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Options) -> bool
pub const fn intersects(&self, other: Options) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Options) -> bool
pub const fn contains(&self, other: Options) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Options)
pub fn remove(&mut self, other: Options)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Options)
pub fn toggle(&mut self, other: Options)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Options, value: bool)
pub fn set(&mut self, other: Options, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Options) -> Options
pub const fn intersection(self, other: Options) -> Options
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Options) -> Options
pub const fn union(self, other: Options) -> Options
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Options) -> Options
pub const fn difference(self, other: Options) -> Options
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Options) -> Options
pub const fn symmetric_difference(self, other: Options) -> Options
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Options
pub const fn complement(self) -> Options
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Options
impl Options
Sourcepub const fn iter(&self) -> Iter<Options>
pub const fn iter(&self) -> Iter<Options>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Options>
pub const fn iter_names(&self) -> IterNames<Options>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.